@@ -1,20 +1,18 @@
-from __future__ import absolute_import, unicode_literals
-
-import os
 import sys
 import subprocess
 
 import pytest
 
 from . import namespaces
+from setuptools.command import test
 
 
 class TestNamespaces:
 
-    @pytest.mark.xfail(sys.version_info < (3, 5),
-        reason="Requires importlib.util.module_from_spec")
-    @pytest.mark.skipif(bool(os.environ.get("APPVEYOR")),
-        reason="https://github.com/pypa/setuptools/issues/851")
+    @pytest.mark.skipif(
+        sys.version_info < (3, 5),
+        reason="Requires importlib.util.module_from_spec",
+    )
     def test_mixed_site_and_non_site(self, tmpdir):
         """
         Installing two packages sharing the same namespace, one installed
@@ -27,10 +25,11 @@ class TestNamespaces:
         site_packages = tmpdir / 'site-packages'
         path_packages = tmpdir / 'path-packages'
         targets = site_packages, path_packages
-        python_path = os.pathsep.join(map(str, targets))
         # use pip to install to the target directory
         install_cmd = [
-            'pip',
+            sys.executable,
+            '-m',
+            'pip.__main__',
             'install',
             str(pkg_A),
             '-t', str(site_packages),
@@ -38,7 +37,9 @@ class TestNamespaces:
         subprocess.check_call(install_cmd)
         namespaces.make_site_dir(site_packages)
         install_cmd = [
-            'pip',
+            sys.executable,
+            '-m',
+            'pip.__main__',
             'install',
             str(pkg_B),
             '-t', str(path_packages),
@@ -48,11 +49,9 @@ class TestNamespaces:
             sys.executable,
             '-c', 'import myns.pkgA; import myns.pkgB',
         ]
-        env = dict(PYTHONPATH=python_path)
-        subprocess.check_call(try_import, env=env)
+        with test.test.paths_on_pythonpath(map(str, targets)):
+            subprocess.check_call(try_import)
 
-    @pytest.mark.skipif(bool(os.environ.get("APPVEYOR")),
-        reason="https://github.com/pypa/setuptools/issues/851")
     def test_pkg_resources_import(self, tmpdir):
         """
         Ensure that a namespace package doesn't break on import
@@ -61,23 +60,23 @@ class TestNamespaces:
         pkg = namespaces.build_namespace_package(tmpdir, 'myns.pkgA')
         target = tmpdir / 'packages'
         target.mkdir()
-        env = dict(PYTHONPATH=str(target))
         install_cmd = [
             sys.executable,
-            '-m', 'easy_install',
-            '-d', str(target),
+            '-m', 'pip',
+            'install',
+            '-t', str(target),
             str(pkg),
         ]
-        subprocess.check_call(install_cmd, env=env)
+        with test.test.paths_on_pythonpath([str(target)]):
+            subprocess.check_call(install_cmd)
         namespaces.make_site_dir(target)
         try_import = [
             sys.executable,
             '-c', 'import pkg_resources',
         ]
-        subprocess.check_call(try_import, env=env)
+        with test.test.paths_on_pythonpath([str(target)]):
+            subprocess.check_call(try_import)
 
-    @pytest.mark.skipif(bool(os.environ.get("APPVEYOR")),
-        reason="https://github.com/pypa/setuptools/issues/851")
     def test_namespace_package_installed_and_cwd(self, tmpdir):
         """
         Installing a namespace packages but also having it in the current
@@ -87,7 +86,9 @@ class TestNamespaces:
         target = tmpdir / 'packages'
         # use pip to install to the target directory
         install_cmd = [
-            'pip',
+            sys.executable,
+            '-m',
+            'pip.__main__',
             'install',
             str(pkg_A),
             '-t', str(target),
@@ -100,5 +101,34 @@ class TestNamespaces:
             sys.executable,
             '-c', 'import pkg_resources; import myns.pkgA',
         ]
-        env = dict(PYTHONPATH=str(target))
-        subprocess.check_call(pkg_resources_imp, env=env, cwd=str(pkg_A))
+        with test.test.paths_on_pythonpath([str(target)]):
+            subprocess.check_call(pkg_resources_imp, cwd=str(pkg_A))
+
+    def test_packages_in_the_same_namespace_installed_and_cwd(self, tmpdir):
+        """
+        Installing one namespace package and also have another in the same
+        namespace in the current working directory, both of them must be
+        importable.
+        """
+        pkg_A = namespaces.build_namespace_package(tmpdir, 'myns.pkgA')
+        pkg_B = namespaces.build_namespace_package(tmpdir, 'myns.pkgB')
+        target = tmpdir / 'packages'
+        # use pip to install to the target directory
+        install_cmd = [
+            sys.executable,
+            '-m',
+            'pip.__main__',
+            'install',
+            str(pkg_A),
+            '-t', str(target),
+        ]
+        subprocess.check_call(install_cmd)
+        namespaces.make_site_dir(target)
+
+        # ensure that all packages import and pkg_resources imports
+        pkg_resources_imp = [
+            sys.executable,
+            '-c', 'import pkg_resources; import myns.pkgA; import myns.pkgB',
+        ]
+        with test.test.paths_on_pythonpath([str(target)]):
+            subprocess.check_call(pkg_resources_imp, cwd=str(pkg_B))
